@@ -11,26 +11,24 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Check;
-{
-  $Dist::Zilla::Plugin::Git::Check::VERSION = '2.025';
-}
-# ABSTRACT: check your git repository before releasing
+# ABSTRACT: Check your git repository before releasing
+
+our $VERSION = '2.041';
 
 use Moose;
 use namespace::autoclean 0.09;
 use Moose::Util::TypeConstraints qw(enum);
+use MooseX::Types::Moose qw(Bool);
 
-use constant _DieWarnIgnore => do { enum [qw[ die warn ignore ]] };
+with 'Dist::Zilla::Role::AfterBuild',
+    'Dist::Zilla::Role::BeforeRelease',
+    'Dist::Zilla::Role::Git::Repo';
+with 'Dist::Zilla::Role::Git::DirtyFiles',
+    'Dist::Zilla::Role::GitConfig';
 
-with 'Dist::Zilla::Role::AfterBuild';
-with 'Dist::Zilla::Role::BeforeRelease';
-with 'Dist::Zilla::Role::Git::Repo';
-with 'Dist::Zilla::Role::Git::DirtyFiles';
-with 'Dist::Zilla::Role::GitConfig';
+has build_warnings => ( is=>'ro', isa => Bool, default => 0 );
 
-has build_warnings => ( is=>'ro', isa => 'Bool', default => 0 );
-
-has untracked_files => ( is=>'ro', isa => _DieWarnIgnore, default => 'die' );
+has untracked_files => ( is=>'ro', isa => enum([qw(die warn ignore)]), default => 'die' );
 
 sub _git_config_mapping { +{
    changelog => '%{changelog}s',
@@ -46,6 +44,7 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
+        # build_warnings does not affect the build outcome; do not need to track it
         untracked_files => $self->untracked_files,
     };
 
@@ -135,11 +134,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::Check - check your git repository before releasing
+Dist::Zilla::Plugin::Git::Check - Check your git repository before releasing
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 SYNOPSIS
 
@@ -154,8 +153,8 @@ In your F<dist.ini>:
 
 =head1 DESCRIPTION
 
-This plugin checks that git is in a clean state before releasing. The
-following checks are performed before releasing:
+This plugin checks that your Git repo is in a clean state before releasing.
+The following checks are performed before releasing:
 
 =over 4
 
@@ -198,11 +197,24 @@ total number of untracked files.
 =for Pod::Coverage after_build
     before_release
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
