@@ -11,14 +11,12 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Commit;
-{
-  $Dist::Zilla::Plugin::Git::Commit::VERSION = '2.025';
-}
-# ABSTRACT: commit dirty files
+# ABSTRACT: Commit dirty files
+
+our $VERSION = '2.041';
 
 use namespace::autoclean;
 use File::Temp           qw{ tempfile };
-use List::Util           qw{ first };
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
@@ -26,24 +24,10 @@ use MooseX::Types::Path::Tiny 0.010 qw{ Paths };
 use Path::Tiny 0.048 qw(); # subsumes
 use Cwd;
 
-use String::Formatter method_stringf => {
-  -as => '_format_string',
-  codes => {
-    c => sub { $_[0]->_get_changes },
-    d => sub { require DateTime;
-               DateTime->now(time_zone => $_[0]->time_zone)
-                       ->format_cldr($_[1] || 'dd-MMM-yyyy') },
-    n => sub { "\n" },
-    N => sub { $_[0]->zilla->name },
-    t => sub { $_[0]->zilla->is_trial
-                   ? (defined $_[1] ? $_[1] : '-TRIAL') : '' },
-    v => sub { $_[0]->zilla->version },
-  },
-};
-
-with 'Dist::Zilla::Role::AfterRelease';
-with 'Dist::Zilla::Role::Git::Repo';
+with 'Dist::Zilla::Role::AfterRelease',
+    'Dist::Zilla::Role::Git::Repo';
 with 'Dist::Zilla::Role::Git::DirtyFiles';
+with 'Dist::Zilla::Role::Git::StringFormatter';
 with 'Dist::Zilla::Role::GitConfig';
 
 sub _git_config_mapping { +{
@@ -53,7 +37,6 @@ sub _git_config_mapping { +{
 # -- attributes
 
 has commit_msg => ( ro, isa=>Str, default => 'v%v%n%n%c' );
-has time_zone  => ( ro, isa=>Str, default => 'local' );
 has add_files_in  => ( ro, isa=> Paths, coerce => 1, default => sub { [] });
 
 
@@ -69,7 +52,8 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        map { $_ => $self->$_ } qw(commit_msg time_zone add_files_in),
+        commit_msg => $self->commit_msg,
+        add_files_in => [ sort @{ $self->add_files_in } ],
     };
 
     return $config;
@@ -116,45 +100,19 @@ sub after_release {
 }
 
 
+#pod =method get_commit_message
+#pod
+#pod This method returns the commit message.  The default implementation
+#pod reads the Changes file to get the list of changes in the just-released version.
+#pod
+#pod =cut
 
 sub get_commit_message {
     my $self = shift;
 
-    return _format_string($self->commit_msg, $self);
+    return $self->_format_string($self->commit_msg);
 } # end get_commit_message
 
-# -- private methods
-
-sub _get_changes {
-    my $self = shift;
-
-    # parse changelog to find commit message
-    my $cl_name   = $self->changelog;
-    my $changelog = first { $_->name eq $cl_name } @{ $self->zilla->files };
-    unless ($changelog) {
-      $self->log("WARNING: Unable to find $cl_name");
-      return '';
-    }
-    my $newver    = $self->zilla->version;
-    $changelog->content =~ /
-      ^\Q$newver\E(?![_.]*[0-9]).*\n # from line beginning with version number
-      ( (?: (?> .* ) (?:\n|\z) )*? ) # capture as few lines as possible
-      (?: (?> \s* ) ^\S | \z )       # until non-indented line or EOF
-    /xm or do {
-      $self->log("WARNING: Unable to find $newver in $cl_name");
-      return '';
-    };
-
-    (my $changes = $1) =~ s/^\s*\n//; # Remove leading blank lines
-
-    $self->log("WARNING: No changes listed under $newver in $cl_name")
-        unless length $changes;
-
-    # return commit message
-    return $changes;
-} # end _get_changes
-
-
 1;
 
 __END__
@@ -165,11 +123,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::Commit - commit dirty files
+Dist::Zilla::Plugin::Git::Commit - Commit dirty files
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 SYNOPSIS
 
@@ -210,52 +168,19 @@ This option may appear multiple times. This is used to add files
 generated during build-time to the repository, for example. The default
 list is empty.
 
-Note: The files have to be generated between those phases: BeforeRelease
+Note: The files have to be generated between the phases BeforeRelease
 E<lt>-E<gt> AfterRelease, and after Git::Check + before Git::Commit.
 
 =item * commit_msg - the commit message to use. Defaults to
 C<v%v%n%n%c>, meaning the version number and the list of changes.
+The L<formatting codes|Dist::Zilla::Role::Git::StringFormatter/DESCRIPTION>
+are documented under L<Dist::Zilla::Role::Git::StringFormatter>.
 
 =item * time_zone - the time zone to use with C<%d>.  Can be any
 time zone name accepted by DateTime.  Defaults to C<local>.
 
 =back
 
-You can use the following codes in commit_msg:
-
-=over 4
-
-=item C<%c>
-
-The list of changes in the just-released version (read from C<changelog>).
-It will include lines between the current version and timestamp and
-the next non-indented line, except that blank lines at the beginning
-or end are removed.  It normally ends in a newline.
-
-=item C<%{dd-MMM-yyyy}d>
-
-The current date.  You can use any CLDR format supported by
-L<DateTime>.  A bare C<%d> means C<%{dd-MMM-yyyy}d>.
-
-=item C<%n>
-
-a newline
-
-=item C<%N>
-
-the distribution name
-
-=item C<%{-TRIAL}t>
-
-Expands to -TRIAL (or any other supplied string) if this is a trial
-release, or the empty string if not.  A bare C<%t> means C<%{-TRIAL}t>.
-
-=item C<%v>
-
-the distribution version
-
-=back
-
 =head1 METHODS
 
 =head2 get_commit_message
@@ -265,11 +190,24 @@ reads the Changes file to get the list of changes in the just-released version.
 
 =for Pod::Coverage after_release mvp_multivalue_args
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
