@@ -11,10 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::CommitBuild;
-{
-  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '2.025';
-}
-# ABSTRACT: checkin build results on separate branch
+# ABSTRACT: Check in build results on separate branch
+
+our $VERSION = '2.041';
 
 use Git::Wrapper 0.021 ();      # need -STDIN
 use IPC::Open3;
@@ -24,11 +23,10 @@ use File::Spec::Functions qw/ rel2abs catfile /;
 use File::Temp;
 use Moose;
 use namespace::autoclean;
-use MooseX::AttributeShortcuts;
 use Path::Tiny qw();
 use MooseX::Types::Path::Tiny qw( Path );
 use MooseX::Has::Sugar;
-use MooseX::Types::Moose qw{ Str };
+use MooseX::Types::Moose qw{ Str Bool };
 use Cwd qw(abs_path);
 use Try::Tiny;
 
@@ -54,8 +52,9 @@ use String::Formatter (
 # debugging...
 #use Smart::Comments '###';
 
-with 'Dist::Zilla::Role::AfterBuild', 'Dist::Zilla::Role::AfterRelease';
-with 'Dist::Zilla::Role::Git::Repo';
+with 'Dist::Zilla::Role::AfterBuild',
+    'Dist::Zilla::Role::AfterRelease',
+    'Dist::Zilla::Role::Git::Repo';
 
 # -- attributes
 
@@ -67,7 +66,7 @@ has build_root => ( rw, coerce => 1, isa => Path );
 
 has _source_branch => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     lazy    => 1,
     init_arg=> undef,
     default => sub {
@@ -77,7 +76,7 @@ has _source_branch => (
 
 has multiple_inheritance => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0,
 );
 
@@ -95,8 +94,9 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        map { $_ => $self->$_ }
-            qw(branch release_branch message release_message build_root multiple_inheritance),
+        (map { $_ => $self->$_ }
+            qw(branch release_branch message release_message build_root)),
+        multiple_inheritance => $self->multiple_inheritance ? 1 : 0,
     };
 
     return $config;
@@ -207,11 +207,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::CommitBuild - checkin build results on separate branch
+Dist::Zilla::Plugin::Git::CommitBuild - Check in build results on separate branch
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 SYNOPSIS
 
@@ -287,11 +287,24 @@ source commit from which the build was generated.
 =for Pod::Coverage after_build
     after_release
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
