@@ -11,10 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Init;
-{
-  $Dist::Zilla::Plugin::Git::Init::VERSION = '2.025';
-}
-# ABSTRACT: initialize git repository on dzil new
+# ABSTRACT: Initialize git repository on dzil new
+
+our $VERSION = '2.041';
 
 our %transform = (
   lc => sub { lc shift },
@@ -32,35 +31,37 @@ use String::Formatter method_stringf => {
   },
 };
 
+use MooseX::Types::Moose qw(Str Bool ArrayRef);
 with 'Dist::Zilla::Role::AfterMint';
+use namespace::autoclean;
 
 has commit_message => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => 'initial commit',
 );
 
 has commit => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 1,
 );
 
 has branch => (
     is      => 'ro',
-    isa     => 'Str',
+    isa     => Str,
     default => '',
 );
 
 has remotes => (
   is   => 'ro',
-  isa  => 'ArrayRef[Str]',
+  isa  => ArrayRef[Str],
   default => sub { [] },
 );
 
 has config_entries => (
   is   => 'ro',
-  isa  => 'ArrayRef[Str]',
+  isa  => ArrayRef[Str],
   default => sub { [] },
 );
 
@@ -107,11 +108,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::Init - initialize git repository on dzil new
+Dist::Zilla::Plugin::Git::Init - Initialize git repository on dzil new
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 SYNOPSIS
 
@@ -175,11 +176,24 @@ the name in lower case or upper case, respectively.
 
 =for Pod::Coverage after_mint mvp_aliases mvp_multivalue_args
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
