@@ -11,13 +11,13 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
-{
-  $Dist::Zilla::PluginBundle::Git::VERSION = '2.025';
-}
-# ABSTRACT: all git plugins in one go
+# ABSTRACT: All git plugins in one bundle
+
+our $VERSION = '2.041';
 
 use Moose;
 use Module::Runtime 'use_module';
+use namespace::autoclean;
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -65,11 +65,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::Git - all git plugins in one go
+Dist::Zilla::PluginBundle::Git - All git plugins in one bundle
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 SYNOPSIS
 
@@ -86,23 +86,65 @@ In your F<dist.ini>:
 
 =head1 DESCRIPTION
 
-This is a plugin bundle to load all git plugins. It is equivalent to:
+This is a plugin bundle to load the most common Git plugins.
+It is equivalent to:
 
     [Git::Check]
     [Git::Commit]
     [Git::Tag]
     [Git::Push]
 
-The options are passed through to the plugins.
+Any options given are passed through to each plugin.  See each
+plugin's documentation for the options it supports.  (Plugins just
+ignore options they don't understand.)
 
 =for Pod::Coverage bundle_config
     mvp_multivalue_args
 
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<Git::Check|Dist::Zilla::Plugin::Git::Check>
+
+Before a release, check that the repo is in a clean state
+(you have committed your changes).
+
+=item * L<Git::Commit|Dist::Zilla::Plugin::Git::Commit>
+
+After a release, commit updated files.
+
+=item * L<Git::Tag|Dist::Zilla::Plugin::Git::Tag>
+
+After a release, tag the just-released version.
+
+=item * L<Git::Push|Dist::Zilla::Plugin::Git::Push>
+
+After a release, push the released code & tag to your public repo.
+
+=back
+
+For a list of Git plugins in this distribution that are not part of
+this bundle, see L<Dist::Zilla::Plugin::Git>.
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
