@@ -11,19 +11,16 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Role::Git::DirtyFiles;
-{
-  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '2.025';
-}
-# ABSTRACT: provide the allow_dirty & changelog attributes
+# ABSTRACT: Provide the allow_dirty & changelog attributes
+
+our $VERSION = '2.041';
 
 use Moose::Role;
-use Moose::Autobox;
 use MooseX::Types::Moose qw{ Any ArrayRef Str RegexpRef };
 use MooseX::Types::Path::Tiny 0.010 qw{ Paths to_Paths };
 use Moose::Util::TypeConstraints;
 
 use namespace::autoclean;
-use List::Util 'first';
 use Path::Tiny 0.048 qw(); # subsumes
 use Try::Tiny;
 
@@ -31,6 +28,29 @@ requires qw(log_fatal repo_root zilla);
 
 # -- attributes
 
+#pod =attr allow_dirty
+#pod
+#pod A list of paths that are allowed to be dirty in the git checkout.
+#pod Defaults to C<dist.ini> and the changelog (as defined per the
+#pod C<changelog> attribute.
+#pod
+#pod If your C<repo_root> is not the default (C<.>), then these pathnames
+#pod are relative to Dist::Zilla's root directory, not the Git root directory.
+#pod
+#pod =attr allow_dirty_match
+#pod
+#pod A list of regular expressions that match paths allowed to be dirty in
+#pod the git checkout.  This is combined with C<allow_dirty>.  Defaults to
+#pod the empty list.
+#pod
+#pod The paths being matched are relative to the Git root directory, even
+#pod if your C<repo_root> is not the default (C<.>).
+#pod
+#pod =attr changelog
+#pod
+#pod The name of the changelog. Defaults to C<Changes>.
+#pod
+#pod =cut
 
 {
   # We specifically allow the empty string to represent the empty list.
@@ -82,19 +102,32 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        map { $_ => $self->$_ } qw(allow_dirty allow_dirty_match changelog),
+        (map { $_ => [ sort @{ $self->$_ } ] } qw(allow_dirty allow_dirty_match)),
+        changelog => $self->changelog,
     };
 
     return $config;
 };
 
+#pod =method list_dirty_files
+#pod
+#pod   my @dirty = $plugin->list_dirty_files($git, $listAllowed);
+#pod
+#pod This returns a list of the modified or deleted files in C<$git>,
+#pod filtered against the C<allow_dirty> attribute.  If C<$listAllowed> is
+#pod true, only allowed files are listed.  If it's false, only files that
+#pod are not allowed to be dirty are listed.
+#pod
+#pod In scalar context, returns the number of dirty files.
+#pod
+#pod =cut
 
 sub list_dirty_files
 {
   my ($self, $git, $listAllowed) = @_;
 
   my $git_root  = $self->repo_root;
-  my @filenames = $self->allow_dirty->flatten;
+  my @filenames = @{ $self->allow_dirty };
 
   if ($git_root ne '.') {
     # Interpret allow_dirty relative to the dzil root
@@ -117,7 +150,7 @@ sub list_dirty_files
     }
   } # end if git root ne dzil root
 
-  my $allowed = join '|', $self->allow_dirty_match->flatten, map { qr{^\Q$_\E$} } @filenames;
+  my $allowed = join '|', @{ $self->allow_dirty_match }, map { qr{^\Q$_\E$} } @filenames;
 
   $allowed = qr/(?!X)X/ if $allowed eq ''; # this cannot match anything
 
@@ -136,11 +169,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Role::Git::DirtyFiles - provide the allow_dirty & changelog attributes
+Dist::Zilla::Role::Git::DirtyFiles - Provide the allow_dirty & changelog attributes
 
 =head1 VERSION
 
-version 2.025
+version 2.041
 
 =head1 DESCRIPTION
 
@@ -186,11 +219,24 @@ In scalar context, returns the number of dirty files.
 
 =for Pod::Coverage mvp_multivalue_args
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Git>
+(or L<bug-Dist-Zilla-Plugin-Git@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Git@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://www.listbox.com/subscribe/?list_id=139292>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Jerome Quelin
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2009 by Jerome Quelin.
 
