@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 #---------------------------------------------------------------------
-package t::Util;
+package Util;
 #
 # Copyright 2012 Christopher J. Madsen
 #
@@ -43,11 +43,12 @@ our ($base_dir, $base_dir_pushed, $dist_dir, $git_dir, $git, $zilla);
 use Exporter ();
 our @ISA    = qw(Exporter);
 our @EXPORT = qw($base_dir $git_dir $git $zilla
-                 append_and_add append_to_file init_test keep_tempdir
+                 append_and_add append_to_file chdir_original_cwd
+                 clean_environment init_repo init_test keep_tempdir
                  new_zilla_from_repo
                  skip_unless_git_version slurp_text_file
                  zilla_log_is);
-our @EXPORT_OK = qw($dist_dir throws_ok zilla_version);
+our @EXPORT_OK = qw($dist_dir zilla_version);
 
 my $original_cwd;
 
@@ -80,6 +81,37 @@ sub append_to_file {
   close $fh;
 }
 
+#---------------------------------------------------------------------
+sub chdir_original_cwd {
+  chdir $original_cwd or die "Can't chdir $original_cwd: $!";
+}
+
+#---------------------------------------------------------------------
+# Internal function shared by clean_environment & init_test
+
+sub _clean_environment
+{
+  my $homedir = shift;
+
+  delete $ENV{V}; # In case we're being released with a manual version
+  delete $ENV{$_} for grep /^G(?:IT|PG)_/i, keys %ENV;
+
+  $ENV{HOME} = $ENV{GNUPGHOME} = $homedir;
+  $ENV{GIT_CONFIG_NOSYSTEM} = 1; # Don't read /etc/gitconfig
+} # end _clean_environment
+
+#---------------------------------------------------------------------
+# Create a mock home directory & clear the environment
+
+sub clean_environment
+{
+  my $tempdir = Path::Tiny->tempdir( CLEANUP => 1 );
+
+  _clean_environment($tempdir->stringify);
+
+  $tempdir;            # Object must remain in scope until you're done
+} # end clean_environment
+
 #---------------------------------------------------------------------
 sub init_test
 {
@@ -92,10 +124,9 @@ sub init_test
   $base_dir = $base_dir_pushed->absolute;
 
   # Mock HOME to keep user's global Git config from causing problems:
-  mkdir($ENV{HOME} = $base_dir->child('home')->stringify)
-      or die "Failed to create $ENV{HOME}: $!";
-
-  delete $ENV{V}; # In case we're being released with a manual version
+  my $homedir = $base_dir->child('home')->stringify;
+  mkdir($homedir) or die "Failed to create $homedir: $!";
+  _clean_environment($homedir);
 
   # Create the test repo:
   $git_dir = $base_dir->child('repo');
@@ -112,15 +143,45 @@ sub init_test
     }
   } # end if add_files
 
-  my $pushd = pushd($git_dir);
-  system "git init --quiet" and die "Can't initialize repo";
+  $git = init_repo($git_dir);
+} # end init_test
 
-  $git = Git::Wrapper->new("$git_dir");
+#---------------------------------------------------------------------
+# Init a Git repo and set defaults.
+# Returns a Git::Wrapper for the new repo.
+# If @initial_files are supplied, also does add -f and commits.
+
+sub init_repo
+{
+  my ($git_dir, @initial_files) = @_;
+
+  {
+    my $pushd = pushd($git_dir);
+    system qw(git init --quiet) and die "Can't initialize repo in $git_dir";
+  }
+
+  my $git = Git::Wrapper->new("$git_dir");
 
   $git->config( 'push.default' => 'matching' ); # compatibility with Git 1.8
   $git->config( 'user.name'  => 'dzp-git test' );
   $git->config( 'user.email' => 'dzp-git@test' );
-} # end init_test
+
+  # If core.autocrlf is true, then git add may hang on Windows.
+  # This is probably a bug in Git::Wrapper, but a workaround is to set
+  # autocrlf to false.  It seems to be caused by these warning messages
+  # (from git version 1.8.5.2.msysgit.0):
+  #   warning: LF will be replaced by CRLF in .gitignore.
+  #   The file will have its original line endings in your working directory.
+  $git->config( 'core.autocrlf' => 'false' );
+
+  if (@initial_files) {
+    # Don't use --force, because only -f works before git 1.5.6
+    $git->add(-f => @initial_files);
+    $git->commit( { message => 'initial commit' } );
+  }
+
+  $git;
+} # end init_repo
 
 #---------------------------------------------------------------------
 sub keep_tempdir
@@ -143,7 +204,7 @@ sub skip_unless_git_version
   my $need_version = shift;
 
   $git_version = version->parse(
-    Git::Wrapper->new('.')->version =~ m[^( \d+ \. \d[.\d]+ )]x
+    Git::Wrapper->new('.')->version =~ m[^( \d+ (?: \. \d+ )+ )]x
   ) unless defined $git_version;
 
   if ( $git_version < version->parse($need_version) ) {
@@ -171,24 +232,6 @@ sub slurp_text_file
   };
 } # end slurp_text_file
 
-#---------------------------------------------------------------------
-# DON'T USE THIS FUNCTION
-#
-# It's a limited clone of Test::Exception's throws_ok I wrote to make
-# it easier to port the tests from Test::Exception to Test::Fatal.
-# Use Test::Fatal directly instead.
-
-sub throws_ok (&$;$)
-{
-  my ($coderef, $expected, $name) = @_;
-
-  # The test program must load Test::Fatal
-  my $exception = &Test::Fatal::exception($coderef);
-
-  local $Test::Builder::Level = $Test::Builder::Level + 1;
-  like( $exception, $expected, $name);
-} # end throws_ok
-
 #---------------------------------------------------------------------
 sub zilla_log_is
 {
